@@ -1,6 +1,8 @@
 from .base import BackendBase
 from .bk_qiniu import Qiniu
+from .bk_wy import WYSF
 
 backend_factory = {
-    'qiniu': Qiniu
+    'qiniu': Qiniu,
+    'wysf': WYSF
 }
\ No newline at end of file
