@@ -7,10 +7,19 @@ class BackendBase:
     
     def put_buffer(self, buffer, bucket, bucket_name):
         pass
+
+    async def put_async(self, filename, bucket, bucket_name):
+        pass
+    
+    async def put_buffer_async(self, buffer, bucket, bucket_name):
+        pass
     
     def get(self, filename, bucket, bucket_name):
         pass
     
     def geturl(self, entrypoint):
         return entrypoint
+
+    async def get_async(self, filename, bucket, bucket_name):
+        pass
     
\ No newline at end of file
