@@ -158,33 +158,53 @@ class Client(Singleton):
         except:
             pass
         self.index_cache.set(key, _val, expire=ttl)
+
+    def __put_to_cloud(self, path, bucket, bucket_name, tmp=True, tries=0):
+        prefix, backend = self._random_pick_backend()
+        
+        ret, e = backend.put(path, bucket, bucket_name, tmp)
+        if ret:
+            url = '{}://{}'.format(prefix, e)
+            return True, url
+        else:
+            if tries > 3:
+                return False, None
+            else:
+                self.__put_to_cloud(path, bucket, bucket_name, tmp, tries+1)
             
     def put_to_cloud(self, path, bucket, bucket_name, tmp=True):
         cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
         cache_data = self.get_cache(cache_key, toObj=False)
         if cache_data is None:
-            prefix, backend = self._random_pick_backend()
-            
-            ret, e = backend.put(path, bucket, bucket_name, tmp)
+            ret, e = self.__put_to_cloud(path, bucket, bucket_name, tmp)
             if ret:
-                url = '{}://{}'.format(prefix, e)
-                self.cache(cache_key, url)
-                return True, url
+                self.cache(cache_key, e)
+
             return ret, e
         else:
             return True, cache_data
 
+    async def __put_to_cloud_async(self, path, bucket, bucket_name, tmp=True, tries=0):
+        prefix, backend = self._random_pick_backend()
+        
+        ret, e = await backend.put_async(path, bucket, bucket_name, tmp)
+        if ret:
+            url = '{}://{}'.format(prefix, e)
+            return True, url
+        else:
+            if tries > 3:
+                return False, None
+            else:
+                await self.__put_to_cloud_async(path, bucket, bucket_name, tmp, tries+1)
+
+        
     async def put_to_cloud_async(self, path, bucket, bucket_name, tmp=True):
         cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
         cache_data = await self.get_cache_async(cache_key, toObj=False)
         if cache_data is None:
-            prefix, backend = self._random_pick_backend()
-            
-            ret, e = await backend.put_async(path, bucket, bucket_name, tmp)
+            ret, e = await self.__put_to_cloud_async(path, bucket, bucket_name, tmp)
             if ret:
-                url = '{}://{}'.format(prefix, e)
-                await self.cache_async(cache_key, url)
-                return True, url
+                await self.cache_async(cache_key, e)
             return ret, e
         else:
             return True, cache_data
