@@ -265,7 +265,7 @@ class XRedis(Singleton):
         return conn.zscore(z_name, key)
 
 try:
-    import coredis
+    from redis import asyncio as coredis
 except:
     pass
 
@@ -278,7 +278,6 @@ class XRedisAsync(Singleton):
         self.port = port
         self.db = db
         self.locker = threading.Lock()
-
         pool = coredis.ConnectionPool(host=self.host, password=self.password, port=self.port, db=self.db, decode_responses=True, socket_keepalive=True, retry_on_timeout=True)
         self.conn = coredis.StrictRedis(connection_pool=pool)
             
@@ -324,7 +323,7 @@ class XRedisAsync(Singleton):
 
     async def lock(self, lock_id, ttl=60, tries=0):
         try:
-            conn = self.__get_connection()
+            conn = await self._get_connection()
             print('获取锁 -> {}'.format(lock_id))
             return conn.lock('lock_' + lock_id, blocking_timeout=10, timeout=ttl)
         except LockError as error:
@@ -338,7 +337,7 @@ class XRedisAsync(Singleton):
                 traceback.print_exc()
 
     async def set(self, key, val, expired=None, tries=0):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         try:
             await conn.set(key, val)
             if expired is not None:
@@ -353,7 +352,7 @@ class XRedisAsync(Singleton):
         return False
 
     async def set_expire_time(self, key, expired):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         await conn.expire(key, expired)
 
     async def lock_get(self, key):
@@ -361,133 +360,133 @@ class XRedisAsync(Singleton):
             return await self.get(key)
 
     async def get(self, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         try:
             return await conn.get(key)
         except Exception as e:
             return None
 
     async def delkey(self, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.delete(key)
     
     async def batch_del(self, keys):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         try:
             return await conn.delete(*keys)
         except:
             return False
 
     async def batch_set(self, map: dict):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         await conn.mset(map)
 
     async def batch_get(self, keys):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.mget(keys)
 
     async def list_append(self, key, value, create_if_not_exists=True):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         if create_if_not_exists:
             await conn.rpush(key, value)
         else:
             await conn.rpushx(key, value)
 
     async def list_prepend(self, key, values, create_if_not_exists=True):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         if create_if_not_exists:
             await conn.lpush(key, values)
         else:
             await conn.lpushx(key, values)
 
     async def list_len(self, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.llen(key)
 
     async def list_range(self, key, start, end):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.lrange(key, start, end)
 
     async def list_index(self, key, index):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.lindex(key, index)
 
     async def list_get(self, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.lpop(key)
 
     async def hash_incre(self, hashname, key, amount=1):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.hincrby(hashname, key, amount)
 
     async def hash_decre(self, hashname, key, amount=1):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.hincrby(hashname, key, -amount)
 
     async def hash_set(self, hashname, key, val):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         await conn.hset(hashname, key, val)
 
     async def hash_get(self, hashname, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.hget(hashname, key)
 
     async def hash_keys(self, hashname):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.hkeys(hashname)
 
     async def hash_items(self, hashname):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.hgetall(hashname)
 
     async def hash_contains(self, hashname, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.hexists(hashname, key)
 
     async def hash_del(self, hashname, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.hdel(hashname, key)
 
     async def incr(self, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.incr(key, 1)
     
     async def blpop(self, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.blpop(key)
     
     async def blpush(self, key, val):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.rpush(key, val)
     
     async def lcount(self, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.llen(key)
     
     async def get_pubsub(self):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.pubsub()
     
     async def get_hmget(self, hashname, keys):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.hmget(hashname, keys)
     
     async def zadd(self, z_name, member, val):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.zadd(z_name, val, member)
     
     async def zrem(self, z_name, member):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.zrem(z_name, member)
         
     async def zrange(self, z_name, score_min, score_max):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.zrangebyscore(z_name, score_min, score_max)
     
     async def zcount(self, z_name, score_min, score_max):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.zcount(z_name, score_min, score_max)
 
     async def zscore(self, z_name, key):
-        conn = self.__get_connection()
+        conn = await self._get_connection()
         return await conn.zscore(z_name, key)
